@@ -25,12 +25,6 @@
 #include "gconf-error.h"
 #include "gconf-value.h"
 
-typedef enum
-{
-  GCONF_UNSET_INCLUDING_SCHEMA_NAMES
-} GConfUnsetFlags;
-
-
 /* Sources are not interchangeable; different backend engines will return 
  * GConfSource with different private elements.
  */
